@@ -4,10 +4,11 @@
 const QString iconSilent = "/usr/share/icons/hicolor/48x48/hildon/statusarea_silent.png";
 const QString iconGeneral = "/usr/share/icons/hicolor/48x48/hildon/statusarea_volumelevel4.png";
 
-ProfileChangerWidget::ProfileChangerWidget (QWidget *parent) :
-QMainWindow(parent),
+ProfileChangerWidget::ProfileChangerWidget(QWidget *parent) :
+    QMainWindow(parent),
     ui(new Ui::ProfileChangerWidget)
 {
+    syslog(LOG_WARNING, "profile-changer-widget.cpp setupui");
     ui->setupUi(this);
     setAttribute(Qt::WA_TranslucentBackground);
     if (!QSettings().contains("profilechangerwidget/width"))
@@ -15,7 +16,9 @@ QMainWindow(parent),
     if (!QSettings().contains("profilechangerwidget/height"))
         QSettings().setValue("profilechangerwidget/height", 48);
 
+    syslog(LOG_WARNING, "profile-changer-widget connect onChangeProfileClicked");
     connect(ui->switchButton, SIGNAL(clicked()), this, SLOT(onChangeProfileClicked()));
+    syslog(LOG_WARNING, "profile-changer-widget connect reload");
     this->reloadSettings();
 }
 
