@@ -6,6 +6,7 @@
 #include <qmaemo5homescreenadaptor.h>
 #include <QErrorMessage>
 #include "settingsdialog.h"
+#include "syslog.h"
 
 namespace Ui {
     class ProfileChangerWidget;
@@ -16,14 +17,12 @@ class ProfileChangerWidget : public QMainWindow
     Q_OBJECT
 
 public:
-    ProfileChangerWidget (QWidget *parent = 0);
+    explicit ProfileChangerWidget (QWidget *parent = 0);
     ~ProfileChangerWidget();
 
 
 public slots:
     void onShowSettingsDialog();
-
-private slots:
     void onChangeProfileClicked();
     void reloadSettings();
 
